@@ -1,24 +1,22 @@
-//*****************************************************************************
-//                               CmdGnuCapAC.cpp                              *
-//                              -----------------                             *
-// Started     : 21/02/2008                                                   *
-// Last Update : 12/08/2011                                                   *
-// Copyright   : (C) 2008 by M.S.Waters                                       *
-// Email       : M.Waters@bom.gov.au                                          *
-//*****************************************************************************
+//**************************************************************************************************
+//                                         CmdGnuCapAC.cpp                                         *
+//                                        -----------------                                        *
+// Started     : 2008-02-21                                                                        *
+// Last Update : 2014-12-23                                                                        *
+// Copyright   : (C) 2008 by MSWaters                                                              *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
-#include "gnucap/commands/CmdGnuCapAC.hpp"
+#include "CmdGnuCapAC.hpp"
 
-//*****************************************************************************
+//**************************************************************************************************
 // Constructor.
 
 CmdGnuCapAC::CmdGnuCapAC( void )
@@ -26,19 +24,19 @@ CmdGnuCapAC::CmdGnuCapAC( void )
   bSetDefaults( );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Destructor.
 
 CmdGnuCapAC::~CmdGnuCapAC( )
 {
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Check that the object attributes are valid.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapAC::bValidate( void )
 {
@@ -47,15 +45,15 @@ bool  CmdGnuCapAC::bValidate( void )
   CmdBase::bValidate( );
 
   // Check the sweep start and stop values
-  if( ! ConvertType::bStrToDFlt( m_osStart, &df1 ) )
+  if( ! CnvtType::bStrToFlt( m_osStart, &df1 ) )
     SetErrMsg( wxT("Invalid sweep start value.") );
-  if( ! ConvertType::bStrToDFlt( m_osStop,  &df2 ) )
+  if( ! CnvtType::bStrToFlt( m_osStop,  &df2 ) )
     SetErrMsg( wxT("Invalid sweep stop value.") );
   if( df2 < df1 )
     SetErrMsg( wxT("Start value greater than stop value.") );
 
   // Check the sweep step value and sweep scale
-  if( ! ConvertType::bStrToDFlt( m_osStep, &df3 ) )
+  if( ! CnvtType::bStrToFlt( m_osStep, &df3 ) )
     SetErrMsg( wxT("Invalid sweep step value.") );
   if( df3 <= 0.0 )
     SetErrMsg( wxT("Step value less than or equal to zero.") );
@@ -75,18 +73,18 @@ bool  CmdGnuCapAC::bValidate( void )
   }
 
   // Set the analysis temperature
-  if( ! ConvertType::bStrToDFlt( m_osTempC, &df3 ) )
+  if( ! CnvtType::bStrToFlt( m_osTempC, &df3 ) )
     SetErrMsg( wxT("Invalid analysis temperature value.") );
 
   return( bIsValid( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Set the object attributes to they're default values.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapAC::bSetDefaults( void )
 {
@@ -103,10 +101,10 @@ bool  CmdGnuCapAC::bSetDefaults( void )
 
   m_osTempC  = wxT("27.0");
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Parse the command string.
 //
 // Eg.s : .AC 1.00K 100.00K BY 10.00K TE 27.00 BASIC
@@ -115,8 +113,8 @@ bool  CmdGnuCapAC::bSetDefaults( void )
 //        .AC 1.00K 100.00K OC 10 TE 27.00 BASIC
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapAC::bParse( void )
 {
@@ -139,15 +137,15 @@ bool  CmdGnuCapAC::bParse( void )
 
   // Extract the start value
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStart = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStart = os1;
   else                                                 return( bValidate( ) );
 
   // Is the next field a number?
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df2 )  )
+  if( CnvtType::bStrToFlt( os1, &df2 )  )
   {
     // Extract the stop value
-    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStop = os1;
+    if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStop = os1;
     else                                               return( bValidate( ) );
 
     // Extract the sweep type
@@ -160,7 +158,7 @@ bool  CmdGnuCapAC::bParse( void )
 
     // Extract the step size/count
     os1 = ostk1.GetNextToken( );
-    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStep = os1;
+    if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStep = os1;
     else                                               return( bValidate( ) );
 
     os1 = ostk1.GetNextToken( );
@@ -176,7 +174,7 @@ bool  CmdGnuCapAC::bParse( void )
   if( os1.Upper( ) == wxT("TE") )
   {
     os1 = ostk1.GetNextToken( );
-    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osTempC = os1;
+    if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osTempC = os1;
     else                                               return( bValidate( ) );
   }
 
@@ -186,12 +184,12 @@ bool  CmdGnuCapAC::bParse( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Format the command string.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapAC::bFormat( void )
 {
@@ -209,7 +207,7 @@ bool  CmdGnuCapAC::bFormat( void )
     case eSCALE_LOG : osCmd << wxT(" TI"); break;
     case eSCALE_DEC : osCmd << wxT(" DE"); break;
     case eSCALE_OCT : osCmd << wxT(" OC"); break;
-    default : return( FALSE );
+    default : return( false );
   }
   osCmd << wxT(' ') << m_osStep;
 
@@ -224,7 +222,7 @@ bool  CmdGnuCapAC::bFormat( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Copy the contents of a CmdNgSpiceAC object.
 //
 // Argument List :
@@ -247,7 +245,7 @@ CmdGnuCapAC & CmdGnuCapAC::operator = ( const CmdNgSpiceAC & roCmdAC )
   return( *this );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Print the object attributes.
 //
 // Argument List :
@@ -257,47 +255,37 @@ void  CmdGnuCapAC::Print( const wxString & rosPrefix )
 {
   CmdBase::Print( rosPrefix + wxT("CmdBase::") );
 
-  cout << rosPrefix.mb_str( ) << "m_osStart : "
-       << m_osStart.mb_str( ) << '\n';
-  cout << rosPrefix.mb_str( ) << "m_osStop  : "
-       << m_osStop .mb_str( ) << '\n';
-  cout << rosPrefix.mb_str( ) << "m_osStep  : "
-       << m_osStep .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStart : " << m_osStart.mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStop  : " << m_osStop .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStep  : " << m_osStep .mb_str( ) << '\n';
 
-  cout << rosPrefix.mb_str( ) << "m_eScale  : ";
+  std::cout << rosPrefix.mb_str( ) << "m_eScale  : ";
   switch( m_eScale )
   {
-    case eSCALE_LIN  : cout << "eSCALE_LIN\n";  break;
-    case eSCALE_LOG  : cout << "eSCALE_LOG\n";  break;
-    case eSCALE_DEC  : cout << "eSCALE_DEC\n";  break;
-    case eSCALE_OCT  : cout << "eSCALE_OCT\n";  break;
-    case eSCALE_NONE : cout << "eSCALE_NONE\n"; break;
-    default :          cout << "Invalid\n";     break;
+    case eSCALE_LIN  : std::cout << "eSCALE_LIN\n";  break;
+    case eSCALE_LOG  : std::cout << "eSCALE_LOG\n";  break;
+    case eSCALE_DEC  : std::cout << "eSCALE_DEC\n";  break;
+    case eSCALE_OCT  : std::cout << "eSCALE_OCT\n";  break;
+    case eSCALE_NONE : std::cout << "eSCALE_NONE\n"; break;
+    default :          std::cout << "Invalid\n";     break;
   }
 
-  cout << rosPrefix.mb_str( ) << "m_osTempC : "
-       << m_osTempC.mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osTempC : " << m_osTempC.mb_str( ) << '\n';
 }
 
-//*****************************************************************************
-//                                                                            *
-//                                 Test Utility                               *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                          Test Utility                                           *
+//**************************************************************************************************
 
-#ifdef TEST_CMDGCPAC
-
-// System include files
-
-
-// Application includes
+#ifdef TEST_CMDGNUCAPAC
 
+using  namespace  std;
 
 // Function prototypes
 
 void  Usage( char * psAppName );
 
-//*****************************************************************************
+//**************************************************************************************************
 
 int  main( int argc, char * argv[ ] )
 {
@@ -349,7 +337,7 @@ int  main( int argc, char * argv[ ] )
   exit( EXIT_SUCCESS );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 
 void  Usage( char * psAppName )
 {
@@ -358,6 +346,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_CMDGCPAC
+#endif // TEST_CMDGNUCAPAC
 
-//*****************************************************************************
+//**************************************************************************************************
