@@ -1,24 +1,22 @@
-//*****************************************************************************
-//                              CmdGnuCapDC.cpp                               *
-//                             -----------------                              *
-// Started     : 29/01/2008                                                   *
-// Last Update : 12/08/2011                                                   *
-// Copyright   : (C) 2008 by M.S.Waters                                       *
-// Email       : M.Waters@bom.gov.au                                          *
-//*****************************************************************************
+//**************************************************************************************************
+//                                         CmdGnuCapDC.cpp                                         *
+//                                        -----------------                                        *
+// Started     : 2008-01-29                                                                        *
+// Last Update : 2014-12-23                                                                        *
+// Copyright   : (C) 2008 by MSWaters                                                              *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
-#include "gnucap/commands/CmdGnuCapDC.hpp"
+#include "CmdGnuCapDC.hpp"
 
-//*****************************************************************************
+//**************************************************************************************************
 // Constructor.
 
 CmdGnuCapDC::CmdGnuCapDC( void )
@@ -26,19 +24,19 @@ CmdGnuCapDC::CmdGnuCapDC( void )
   bSetDefaults( );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Destructor.
 
 CmdGnuCapDC::~CmdGnuCapDC( )
 {
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Check that the object attributes are valid.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapDC::bValidate( void )
 {
@@ -47,15 +45,15 @@ bool  CmdGnuCapDC::bValidate( void )
   CmdBase::bValidate( );
 
   // Check the sweep start and stop values
-  if( ! ConvertType::bStrToDFlt( m_osStart, &df1 ) )
+  if( ! CnvtType::bStrToFlt( m_osStart, &df1 ) )
     SetErrMsg( wxT("Invalid sweep start value.") );
-  if( ! ConvertType::bStrToDFlt( m_osStop,  &df2 ) )
+  if( ! CnvtType::bStrToFlt( m_osStop,  &df2 ) )
     SetErrMsg( wxT("Invalid sweep stop value.") );
   if( df2 < df1 )
     SetErrMsg( wxT("Start value greater than stop value.") );
 
   // Check the sweep step value and sweep scale
-  if( ! ConvertType::bStrToDFlt( m_osStep, &df3 ) )
+  if( ! CnvtType::bStrToFlt( m_osStep, &df3 ) )
     SetErrMsg( wxT("Invalid sweep step value.") );
   if( df3 <= 0.0 )
     SetErrMsg( wxT("Step value less than or equal to zero.") );
@@ -79,18 +77,18 @@ bool  CmdGnuCapDC::bValidate( void )
 //    SetErrMsg( wxT("No source component has been selected.") );
 
   // Set the analysis temperature
-  if( ! ConvertType::bStrToDFlt( m_osTempC, &df3 ) )
+  if( ! CnvtType::bStrToFlt( m_osTempC, &df3 ) )
     SetErrMsg( wxT("Invalid analysis temperature value.") );
 
   return( bIsValid( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Set the object attributes to they're default values.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapDC::bSetDefaults( void )
 {
@@ -109,10 +107,10 @@ bool  CmdGnuCapDC::bSetDefaults( void )
 
   m_osTempC  = wxT("0.0");
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Parse the command string.
 //
 // Eg.s : .DC Vin 0.00 100.00m BY 10.00m TE 27.00 BASIC
@@ -120,8 +118,8 @@ bool  CmdGnuCapDC::bSetDefaults( void )
 //        .DC Vin 0.00 100.00m DE 100 TE 27.00 BASIC
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapDC::bParse( void )
 {
@@ -150,12 +148,12 @@ bool  CmdGnuCapDC::bParse( void )
 
   // Extract the start value
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStart = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStart = os1;
   else                                                 return( bValidate( ) );
 
   // Extract the stop voltage
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStop = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStop = os1;
   else                                                 return( bValidate( ) );
 
   // Extract the sweep type: linear, log or steps per decade
@@ -168,7 +166,7 @@ bool  CmdGnuCapDC::bParse( void )
 
   // Extract the step size/count
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStep = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStep = os1;
   else                                                 return( bValidate( ) );
 
   // Extract the analysis temperature
@@ -176,7 +174,7 @@ bool  CmdGnuCapDC::bParse( void )
   if( os1.Upper( ) == wxT("TE") )
   {
     os1 = ostk1.GetNextToken( );
-    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osTempC = os1;
+    if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osTempC = os1;
     else                                               return( bValidate( ) );
   }
 
@@ -186,12 +184,12 @@ bool  CmdGnuCapDC::bParse( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Format the command string.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapDC::bFormat( void )
 {
@@ -226,7 +224,7 @@ bool  CmdGnuCapDC::bFormat( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Copy the contents of a CmdNgSpiceDC object.
 //
 // Argument List :
@@ -249,7 +247,7 @@ CmdGnuCapDC & CmdGnuCapDC::operator = ( const CmdNgSpiceDC & roCmdDC )
   return( *this );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Print the object attributes.
 //
 // Argument List :
@@ -259,50 +257,39 @@ void  CmdGnuCapDC::Print( const wxString & rosPrefix )
 {
   CmdBase::Print( rosPrefix + wxT("CmdBase::") );
 
-  cout << rosPrefix .mb_str( ) << "m_osStart  : "
-       << m_osStart .mb_str( ) << '\n';
-  cout << rosPrefix .mb_str( ) << "m_osStop   : "
-       << m_osStop  .mb_str( ) << '\n';
-  cout << rosPrefix .mb_str( ) << "m_osStep   : "
-       << m_osStep  .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStart  : " << m_osStart .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStop   : " << m_osStop  .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStep   : " << m_osStep  .mb_str( ) << '\n';
 
-  cout << rosPrefix .mb_str( ) << "m_osSource : "
-       << m_osSource.mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osSource : " << m_osSource.mb_str( ) << '\n';
 
-  cout << rosPrefix .mb_str( ) << "m_eScale   : ";
+  std::cout << rosPrefix.mb_str( ) << "m_eScale   : ";
   switch( m_eScale )
   {
-    case eSCALE_LIN  : cout << "eSCALE_LIN\n";  break;
-    case eSCALE_LOG  : cout << "eSCALE_LOG\n";  break;
-    case eSCALE_DEC  : cout << "eSCALE_DEC\n";  break;
-    case eSCALE_OCT  : cout << "eSCALE_OCT\n";  break;
-    case eSCALE_NONE : cout << "eSCALE_NONE\n"; break;
-    default :          cout << "Invalid\n";     break;
+    case eSCALE_LIN  : std::cout << "eSCALE_LIN\n";  break;
+    case eSCALE_LOG  : std::cout << "eSCALE_LOG\n";  break;
+    case eSCALE_DEC  : std::cout << "eSCALE_DEC\n";  break;
+    case eSCALE_OCT  : std::cout << "eSCALE_OCT\n";  break;
+    case eSCALE_NONE : std::cout << "eSCALE_NONE\n"; break;
+    default :          std::cout << "Invalid\n";     break;
   }
 
-  cout << rosPrefix .mb_str( ) << "m_osTempC  : "
-       << m_osTempC .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osTempC  : " << m_osTempC .mb_str( ) << '\n';
 }
 
-//*****************************************************************************
-//                                                                            *
-//                                 Test Utility                               *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                          Test Utility                                           *
+//**************************************************************************************************
 
-#ifdef TEST_CMDGCPDC
-
-// System include files
-
-
-// Application includes
+#ifdef TEST_CMDGNUCAPDC
 
+using  namespace  std;
 
 // Function prototypes
 
 void  Usage( char * psAppName );
 
-//*****************************************************************************
+//**************************************************************************************************
 
 int  main( int argc, char * argv[ ] )
 {
@@ -355,7 +342,7 @@ int  main( int argc, char * argv[ ] )
   exit( EXIT_SUCCESS );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 
 void  Usage( char * psAppName )
 {
@@ -364,6 +351,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_CMDGCPDC
+#endif // TEST_CMDGNUCAPDC
 
-//*****************************************************************************
+//**************************************************************************************************
