@@ -1,24 +1,22 @@
-//*****************************************************************************
-//                              CmdGnuCapOP.cpp                               *
-//                             -----------------                              *
-// Started     : 05/03/2008                                                   *
-// Last Update : 12/08/2011                                                   *
-// Copyright   : (C) 2008 by M.S.Waters                                       *
-// Email       : M.Waters@bom.gov.au                                          *
-//*****************************************************************************
+//**************************************************************************************************
+//                                         CmdGnuCapOP.cpp                                         *
+//                                        -----------------                                        *
+// Started     : 2008-03-05                                                                        *
+// Last Update : 2014-12-23                                                                        *
+// Copyright   : (C) 2008 by MSWaters                                                              *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
-#include "gnucap/commands/CmdGnuCapOP.hpp"
+#include "CmdGnuCapOP.hpp"
 
-//*****************************************************************************
+//**************************************************************************************************
 // Constructor.
 
 CmdGnuCapOP::CmdGnuCapOP( void )
@@ -26,19 +24,19 @@ CmdGnuCapOP::CmdGnuCapOP( void )
   bSetDefaults( );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Destructor.
 
 CmdGnuCapOP::~CmdGnuCapOP( )
 {
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Check that the object attributes are valid.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapOP::bValidate( void )
 {
@@ -47,15 +45,15 @@ bool  CmdGnuCapOP::bValidate( void )
   CmdBase::bValidate( );
 
   // Check the sweep start and stop values
-  if( ! ConvertType::bStrToDFlt( m_osStart, &df1 ) )
+  if( ! CnvtType::bStrToFlt( m_osStart, &df1 ) )
     SetErrMsg( wxT("Invalid sweep start value.") );
-  if( ! ConvertType::bStrToDFlt( m_osStop,  &df2 ) )
+  if( ! CnvtType::bStrToFlt( m_osStop,  &df2 ) )
     SetErrMsg( wxT("Invalid sweep stop value.") );
   if( df2 < df1 )
     SetErrMsg( wxT("Start value greater than stop value.") );
 
   // Check the sweep step value and sweep scale
-  if( ! ConvertType::bStrToDFlt( m_osStep, &df3 ) )
+  if( ! CnvtType::bStrToFlt( m_osStep, &df3 ) )
     SetErrMsg( wxT("Invalid sweep step value.") );
   if( df3 <= 0.0 )
     SetErrMsg( wxT("Step value less than or equal to zero.") );
@@ -81,12 +79,12 @@ bool  CmdGnuCapOP::bValidate( void )
   return( bIsValid( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Set the object attributes to they're default values.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapOP::bSetDefaults( void )
 {
@@ -101,10 +99,10 @@ bool  CmdGnuCapOP::bSetDefaults( void )
 
   m_eScale   = eSCALE_LIN;
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Parse the command string.
 //
 // Eg.s: .OP 27.0 BASIC
@@ -113,8 +111,8 @@ bool  CmdGnuCapOP::bSetDefaults( void )
 //       .OP 27.0 60.0 DE 10 BASIC
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapOP::bParse( void )
 {
@@ -139,13 +137,13 @@ bool  CmdGnuCapOP::bParse( void )
 
   // Extract the start temperature
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) )   m_osStart = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) )   m_osStart = os1;
   else                                                 return( bValidate( ) );
   if( ostk1.CountTokens( ) > 1 )
   {
     // Extract the stop temperature
     os1 = ostk1.GetNextToken( );
-    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStop = os1;
+    if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStop = os1;
     else                                               return( bValidate( ) );
 
     // Extract the sweep type
@@ -158,7 +156,7 @@ bool  CmdGnuCapOP::bParse( void )
 
     // Extract the step size
     os1 = ostk1.GetNextToken( );
-    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStep = os1;
+    if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStep = os1;
     else                                               return( bValidate( ) );
   }
   else
@@ -174,12 +172,12 @@ bool  CmdGnuCapOP::bParse( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Format the command string.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapOP::bFormat( void )
 {
@@ -212,7 +210,7 @@ bool  CmdGnuCapOP::bFormat( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Copy the contents of a CmdNgSpiceDC object.
 //
 // Argument List :
@@ -235,7 +233,7 @@ CmdGnuCapOP & CmdGnuCapOP::operator = ( const CmdNgSpiceDC & roCmdDC )
   return( *this );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Print the object attributes.
 //
 // Argument List :
@@ -245,43 +243,34 @@ void  CmdGnuCapOP::Print( const wxString & rosPrefix )
 {
   CmdBase::Print( rosPrefix + wxT("CmdBase::") );
 
-  cout << rosPrefix.mb_str( ) << "m_osStart : "
-       << m_osStart.mb_str( ) << '\n';
-  cout << rosPrefix.mb_str( ) << "m_osStop  : "
-       << m_osStop .mb_str( ) << '\n';
-  cout << rosPrefix.mb_str( ) << "m_osStep  : "
-       << m_osStep .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStart : " << m_osStart.mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStop  : " << m_osStop .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStep  : " << m_osStep .mb_str( ) << '\n';
 
-  cout << rosPrefix.mb_str( ) << "m_eScale : ";
+  std::cout << rosPrefix.mb_str( ) << "m_eScale : ";
   switch( m_eScale )
   {
-    case eSCALE_LIN  : cout << "eSCALE_LIN\n";  break;
-    case eSCALE_LOG  : cout << "eSCALE_LOG\n";  break;
-    case eSCALE_DEC  : cout << "eSCALE_DEC\n";  break;
-    case eSCALE_NONE : cout << "eSCALE_NONE\n"; break;
-    default :          cout << "Invalid\n";     break;
+    case eSCALE_LIN  : std::cout << "eSCALE_LIN\n";  break;
+    case eSCALE_LOG  : std::cout << "eSCALE_LOG\n";  break;
+    case eSCALE_DEC  : std::cout << "eSCALE_DEC\n";  break;
+    case eSCALE_NONE : std::cout << "eSCALE_NONE\n"; break;
+    default :          std::cout << "Invalid\n";     break;
   }
 }
 
-//*****************************************************************************
-//                                                                            *
-//                                 Test Utility                               *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                          Test Utility                                           *
+//**************************************************************************************************
 
-#ifdef TEST_CMDGCPOP
-
-// System include files
-
-
-// Application includes
+#ifdef TEST_CMDGNUCAPOP
 
+using  namespace  std;
 
 // Function prototypes
 
 void  Usage( char * psAppName );
 
-//*****************************************************************************
+//**************************************************************************************************
 
 int  main( int argc, char * argv[ ] )
 {
@@ -336,7 +325,7 @@ int  main( int argc, char * argv[ ] )
   exit( EXIT_SUCCESS );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 
 void  Usage( char * psAppName )
 {
@@ -345,6 +334,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_CMDGCPOP
+#endif // TEST_CMDGNUCAPOP
 
-//*****************************************************************************
+//**************************************************************************************************
