@@ -1,25 +1,23 @@
-//*****************************************************************************
-//                                FileTasks.cpp                               *
-//                               ---------------                              *
-// Started     : 28/05/2005                                                   *
-// Last Update : 29/08/2011                                                   *
-// Copyright   : (C) 2005 by M.S.Waters                                       *
-// Email       : M.Waters@bom.gov.au                                          *
-//*****************************************************************************
+//**************************************************************************************************
+//                                          FileTasks.cpp                                          *
+//                                         ---------------                                         *
+// Started     : 2005-05-28                                                                        *
+// Last Update : 2015-04-09                                                                        *
+// Copyright   : (C) 2005 by MSWaters                                                              *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
-#include "main/FileTasks.hpp"
-#include "main/FrmMain.hpp"
+#include "FileTasks.hpp"
+#include "FrmMain.hpp"
 
-//*****************************************************************************
+//**************************************************************************************************
 // Constructor.
 //
 // Argument List :
@@ -34,19 +32,19 @@ FileTasks::FileTasks( FrmMain * poFrmMain )
   m_poCfg = (wxConfig *) wxConfig::Get( );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Destructor.
 
 FileTasks::~FileTasks( )
 {
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Execute the schematic import process.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bExecImport( void )
 {
@@ -64,8 +62,8 @@ bool  FileTasks::bExecImport( void )
   m_oPrcGNetList.Print( *poTxtCtl );
 
   // Check for errors in the gnetlist output
-  if( poTxtCtl->GetValue( ).Contains( wxT("ERROR") ) )     bRtn = FALSE;
-  if( poTxtCtl->GetValue( ).Contains( wxT("Backtrace") ) ) bRtn = FALSE;
+  if( poTxtCtl->GetValue( ).Contains( wxT("ERROR") ) )     bRtn = false;
+  if( poTxtCtl->GetValue( ).Contains( wxT("Backtrace") ) ) bRtn = false;
 
   // Delete the process log file
   m_oPrcGNetList.bDelLogFile( );
@@ -73,9 +71,8 @@ bool  FileTasks::bExecImport( void )
   return( bRtn );
 }
 
-//*****************************************************************************
-// Initialize the Guile procedure name to be used by gnetlist when importing
-// schematic files.
+//**************************************************************************************************
+// Initialize the Guile procedure name to be used by gnetlist when importing schematic files.
 
 void  FileTasks::InitGuileProc( void )
 {
@@ -87,7 +84,7 @@ void  FileTasks::InitGuileProc( void )
   bSetGuileProc( os1 );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Initialize the schematic file name/s.
 
 void  FileTasks::InitSchemFiles( void )
@@ -110,7 +107,7 @@ void  FileTasks::InitSchemFiles( void )
   bImport( );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Initialize the netlist file name.
 
 void  FileTasks::InitNetLstFile( void )
@@ -133,19 +130,19 @@ void  FileTasks::InitNetLstFile( void )
 
   // Does the netlist file contain simulator specific information?
   m_poCfg->SetPath( wxT("/Simulator") );
-  if(      m_poFrmMain->m_oSimnNgs.m_oCmdPR.bIsValid( ) )
+  if(      m_poFrmMain->m_oSimnNgSp.m_oCmdPR.bIsValid( ) )
   {
     m_poCfg->Write( wxT("Engine"), CLP_NGSPICE );
-    m_poFrmMain->m_oSimnGcp = m_poFrmMain->m_oSimnNgs;
+    m_poFrmMain->m_oSimnGCap = m_poFrmMain->m_oSimnNgSp;
   }
-  else if( m_poFrmMain->m_oSimnGcp.m_oCmdPR.bIsValid( ) )
+  else if( m_poFrmMain->m_oSimnGCap.m_oCmdPR.bIsValid( ) )
   {
     m_poCfg->Write( wxT("Engine"), CLP_GNUCAP  );
-    m_poFrmMain->m_oSimnNgs = m_poFrmMain->m_oSimnGcp;
+    m_poFrmMain->m_oSimnNgSp = m_poFrmMain->m_oSimnGCap;
   }
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Display a error message dialog when schematic file/s can't be imported.
 
 void  FileTasks::DlgErrSchems( void )
@@ -154,26 +151,25 @@ void  FileTasks::DlgErrSchems( void )
   size_t    sz1;
 
   for( sz1=0; sz1<m_oPrcGNetList.roaGetSchemFiles( ).GetCount( ); sz1++ )
-    os2 << wxT("     ") << m_oPrcGNetList.roGetSchemFile( sz1 ).GetFullPath( )
+    os2 << wxT("     ") << m_oPrcGNetList.rofnGetSchemFile( sz1 ).GetFullPath( )
         << wxT("\n");
 
   if( sz1 > 1 ) os3 = wxT("s were");
   else          os3 = wxT(" was");
 
-  os1 << wxT("The schematic file") << os3
-                             << wxT("n't converted to a netlist correctly :\n")
+  os1 << wxT("The schematic file") << os3 << wxT("n't converted to a netlist correctly :\n")
       << wxT("\n")
       << os2
       << wxT("\n")
-      << wxT("(This is usually because gnetlist encountered problems/s while\n")
-      << wxT("attempting to convert the schematic file/s to a netlist. Try\n")
-      << wxT("examining the Console output to determine where the problem/s\n")
-      << wxT("occurred.)\n");
+      << wxT("This is usually because gnetlist encountered problem/s\n")
+      << wxT("while attempting to convert the schematic file/s to a netlist.  \n")
+      << wxT("Try examining the Console output to determine where the\n")
+      << wxT("problem/s occurred.\n");
 
   m_poFrmMain->DlgErrMsg( wxT("Import Schematic/s Error"), os1 );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Display a error message dialog when a netlist file can't be loaded.
 
 void  FileTasks::DlgErrNetLst( void )
@@ -181,16 +177,15 @@ void  FileTasks::DlgErrNetLst( void )
   wxString  os1;
 
   os1 << wxT("The netlist file wasn't loaded correctly :\n")
-      << wxT("\n")
-      << wxT("     ") << m_oPrcGNetList.roGetNetLstFile().GetFullPath() << wxT('\n')
-      << wxT("\n")
-      << wxT("(This is often because the file is in-complete, empty or\n")
-      << wxT("doesn't exist.)\n");
+      << wxT("\n     ") << m_oPrcGNetList.rofnGetNetLstFile( ).GetFullPath( )
+      << wxT("\n\n")
+      << wxT("This is often because the file is in-complete, empty or  \n")
+      << wxT("doesn't exist.\n");
 
-  m_poFrmMain->DlgErrMsg( wxT("Load Netlist Error"), os1 );
+  m_poFrmMain->DlgErrMsg( wxT("Netlist File Error"), os1 );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Do initialization tasks.
 
 void  FileTasks::Initialize( void )
@@ -200,13 +195,12 @@ void  FileTasks::Initialize( void )
   InitNetLstFile( );
 }
 
-//*****************************************************************************
-// Check that the gnetlist binary can be found, if not display an error
-// message.
+//**************************************************************************************************
+// Check that the gnetlist binary can be found, if not display an error message.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bIsOk_gnetlist( void )
 {
@@ -217,30 +211,32 @@ bool  FileTasks::bIsOk_gnetlist( void )
   {
     if( m_poFrmMain != NULL )
     {
-      os1 << wxT("Can't find ") << m_oPrcGNetList.roGetBinary( ).GetFullName( )
-          << wxT(" which is required to import schematic\nfile/s. ")
-          << wxT("The path is unknown or it hasn't been installed.\n");
-      m_poFrmMain->DlgErrMsg( wxT("Configuration Fault"), os1 );
+      os1 << wxT("Can't find the binary \"") << m_oPrcGNetList.roGetBinary( ).GetFullName( )
+                                                                    << wxT("\" which is required\n")
+          << wxT("to import schematic file/s. The path is unknown   \n")
+          << wxT("or gnetlist hasn't been installed.\n");
+
+      m_poFrmMain->DlgErrMsg( wxT("gnetlist Error"), os1 );
     }
-    return( FALSE );
+    return( false );
   }
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Set the application main frame title.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bSetTitle( void )
 {
   wxFileName  ofn1;
   wxString    os1;
 
-  if( m_poFrmMain == NULL ) return( FALSE );
+  if( m_poFrmMain == NULL ) return( false );
 
   // Create the title line
   os1 << wxT(" ") << APP_NAME;
@@ -259,12 +255,11 @@ bool  FileTasks::bSetTitle( void )
   // Set the main frames title line
   m_poFrmMain->wxFrame::SetTitle( os1 );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
-// Set a Guile procedure name to be used for importing schematic files using
-// gNetList.
+//**************************************************************************************************
+// Set a Guile procedure name to be used for importing schematic files using gNetList.
 //
 // Argument List :
 //   rosPName - The Guile procedure name
@@ -272,7 +267,7 @@ bool  FileTasks::bSetTitle( void )
 
 bool  FileTasks::bSetGuileProc( const wxString & rosPName )
 {
-  if( ! m_oPrcGNetList.bSetGuileProc( rosPName ) ) return( FALSE );
+  if( ! m_oPrcGNetList.bSetGuileProc( rosPName ) ) return( false );
 
   // Record the Guile procedure name currently selected
   m_poCfg->SetPath( wxT("/gNetList") );
@@ -281,50 +276,76 @@ bool  FileTasks::bSetGuileProc( const wxString & rosPName )
   // Write any changes to the configuration file
   m_poCfg->Flush( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Set the schematic file name/s.
 //
 // Argument List :
 //   rosFNames - A string containing the full path and file name/s
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bSetSchemFiles( const wxString & rosFNames )
 {
-  // Attempt to set the schematic file name/s in the gNetList process object
-  if( ! m_oPrcGNetList.bSetSchemFiles( rosFNames ) ) return( FALSE );
+  wxString  os1;
+  size_t    sz1;
+
+  if( rosFNames.IsEmpty( ) )
+  {
+    // Clear the schematic file name/s in the configuration object
+    m_poCfg->SetPath( wxT("/Files") );
+    m_poCfg->Write( wxT("Schematics"), os1 );
+    m_poCfg->Flush( );
+  }
+
+  // Attempt to set the schematic file name/s in the gnetlist process object
+  if( ! m_oPrcGNetList.bSetSchemFiles( rosFNames ) ) return( false );
 
   // Set the schematic file name/s
-  if( m_poFrmMain != NULL )
-    m_poFrmMain->m_oNetLst.bSetSchemFiles( rosFNames );
+  if( m_poFrmMain != NULL ) m_poFrmMain->m_oNetLst.bSetSchemFiles( rosFNames );
 
   // Record the schematic file name/s in the configuration object
+  const wxArrayString & rosa1=rosaGetSchemFiles( );
+  for( sz1=0; sz1<rosa1.GetCount( ); sz1++ )
+  {
+    if( sz1 > 0 ) os1 += wxT(' ');
+    os1 += rosa1[ sz1 ];
+  }
   m_poCfg->SetPath( wxT("/Files") );
-  m_poCfg->Write( wxT("Schematics"), rosFNames );
+  m_poCfg->Write( wxT("Schematics"), os1 );
   m_poCfg->Flush( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Set the netlist file name.
 //
 // Argument List :
 //   psFileName - A string containing the full path and file name
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bSetNetLstFile( const wxString & rosFName )
 {
+  wxString  os1;
+
+  if( rosFName.IsEmpty( ) )
+  {
+    // Clear the netlist file name in the configuration object
+    m_poCfg->SetPath( wxT("/Files") );
+    m_poCfg->Write( wxT("NetList"), os1 );
+    m_poCfg->Flush( );
+  }
+
   // Attempt to set the netlist file name in the gNetList process object
-  if( ! m_oPrcGNetList.bSetNetLstFile( rosFName ) ) return( FALSE );
+  if( ! m_oPrcGNetList.bSetNetLstFile( rosFName ) ) return( false );
 
   // Configure stuff in the main frame
   if( m_poFrmMain != NULL )
@@ -334,14 +355,15 @@ bool  FileTasks::bSetNetLstFile( const wxString & rosFName )
   }
 
   // Record the netlist file name in the configuration object
+  os1 = rosGetNetLstFile( );
   m_poCfg->SetPath( wxT("/Files") );
-  m_poCfg->Write( wxT("NetList"), rosGetNetLstFile( ) );
+  m_poCfg->Write( wxT("NetList"), os1 );
   m_poCfg->Flush( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Get the currently selected Guile procedure.
 //
 // Return Values :
@@ -352,7 +374,7 @@ const wxString & FileTasks::rosGetGuileProc( void )
   return( m_oPrcGNetList.rosGetGuileProc( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Get an array containing the schematic file name/s.
 //
 // Return Values :
@@ -368,14 +390,14 @@ const wxArrayString & FileTasks::rosaGetSchemFiles( void )
 
   for( szt1=0; szt1<m_oPrcGNetList.roaGetSchemFiles( ).GetCount( ); szt1++ )
   {
-    os1 = m_oPrcGNetList.roGetSchemFile( szt1 ).GetFullPath( );
+    os1 = m_oPrcGNetList.rofnGetSchemFile( szt1 ).GetFullPath( );
     if( ! os1.IsEmpty( ) ) osa1.Add( os1 );
   }
 
   return( osa1 );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Get the netlist file name.
 //
 // Return Values :
@@ -385,17 +407,17 @@ const wxString & FileTasks::rosGetNetLstFile( void )
 {
   static  wxString  osNetLstFile;
 
-  osNetLstFile = m_oPrcGNetList.roGetNetLstFile( ).GetFullPath( );
+  osNetLstFile = m_oPrcGNetList.rofnGetNetLstFile( ).GetFullPath( );
 
   return( osNetLstFile );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Display an open file dialog and set the netlist file name.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bDlgOpen( void )
 {
@@ -404,7 +426,7 @@ bool  FileTasks::bDlgOpen( void )
   long           li1;
 
   // Can't display dialogue unless the application main frame has been created
-  if( m_poFrmMain == NULL )                return( FALSE );
+  if( m_poFrmMain == NULL )                return( false );
 
   // Create the different file filters
   os1 << wxT("All files (*)|*|")
@@ -432,29 +454,29 @@ bool  FileTasks::bDlgOpen( void )
   poDlgOpen->SetDirectory( os2 );
 
   // Display file open dialog
-  if( poDlgOpen->ShowModal( ) != wxID_OK ) return( FALSE );
+  if( poDlgOpen->ShowModal( ) != wxID_OK ) return( false );
 
   // Delete temporary files
   bDelTmpFiles( );
 
   // Set the netlist file name
   os1 = poDlgOpen->GetPath( );
-  if( ! bSetNetLstFile( os1 ) )            return( FALSE );
+  if( ! bSetNetLstFile( os1 ) )            return( false );
 
   // Set the path last accessed in the global configuration object
   m_poCfg->SetPath( wxT("/Directories") );
   m_poCfg->Write( wxT("LastAccess"), poDlgOpen->GetDirectory( ) );
   m_poCfg->Flush( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Display an import file/s dialog and set the schematic file name/s.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bDlgImport( void )
 {
@@ -465,7 +487,7 @@ bool  FileTasks::bDlgImport( void )
   size_t         sz1;
 
   // Can't display dialogue unless the application main frame has been created
-  if( m_poFrmMain == NULL )                  return( FALSE );
+  if( m_poFrmMain == NULL )                  return( false );
 
   // Create the different file filters
   os1 << wxT("gSchem files (*.sch)|*.sch|")
@@ -483,15 +505,14 @@ bool  FileTasks::bDlgImport( void )
 #endif
 
   // Create and configure the file import dialog
-  poDlgImport = new wxFileDialog( m_poFrmMain, wxT(""), wxT(""), wxT(""),
-                                  wxT(""), li1 );
+  poDlgImport = new wxFileDialog( m_poFrmMain, wxT(""), wxT(""), wxT(""), wxT(""), li1 );
   poDlgImport->SetMessage( wxT("Import a Schematic File/s") );
   poDlgImport->SetWildcard( os1 );
   poDlgImport->SetFilterIndex( 0 );
   poDlgImport->SetDirectory( os2 );
 
   // Display file import dialog
-  if( poDlgImport->ShowModal( ) != wxID_OK ) return( FALSE );
+  if( poDlgImport->ShowModal( ) != wxID_OK ) return( false );
 
   // Delete temporary files
   bDelTmpFiles( );
@@ -504,7 +525,7 @@ bool  FileTasks::bDlgImport( void )
   os1 = osa1.Item( 0 );
   for( sz1=1; sz1<osa1.GetCount( ); sz1++ )
     os1 << osa1.Item( sz1 ) << wxT(' ');
-  if( ! bSetSchemFiles( os1 ) )              return( FALSE );
+  if( ! bSetSchemFiles( os1 ) )              return( false );
 
   // Set the netlist file name (derive it from the schematic file name)
   bSetNetLstFile( );
@@ -514,13 +535,13 @@ bool  FileTasks::bDlgImport( void )
   m_poCfg->Write( wxT("LastAccess"), poDlgImport->GetDirectory( ) );
   m_poCfg->Flush( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Delete temporary files which may have been generated by this application.
-// Ie. given the circuit description file "<netlist>.ckt" delete files of the
-//     following form :
+//
+// Ie. given the circuit description file "<netlist>.ckt" delete files of the following form :
 //       <netlist>.ngspice.dc, <netlist>.ngspice.ac, ... etc.
 //       <netlist>.gnucap.op,  <netlist>.gnucap.dc, .... etc.
 //       gnetlist.log
@@ -535,15 +556,15 @@ bool  FileTasks::bDelTmpFiles( void )
 
   // Determine the current temporary file management strategy
   m_poCfg->SetPath( wxT("/Main") );
-  m_poCfg->Read( wxT("TmpFileMgt"), &liTmpFileMgt, (long) eTFMS_DELETE );
+  m_poCfg->Read( wxT("TmpFileMgt"), &liTmpFileMgt, (long) eTFM_DELETE );
 
   // Return if nothing needs to be done
-  if( liTmpFileMgt == (long) eTFMS_KEEP )    return( TRUE );
+  if( liTmpFileMgt == (long) eTFM_KEEP )    return( true );
 
   // Get the path to the schematic or circuit description file
-  ofn1 = m_oPrcGNetList.roGetNetLstFile( );
+  ofn1 = m_oPrcGNetList.rofnGetNetLstFile( );
   ofn1.Normalize( );
-  if( !ofn1.IsOk( ) || !ofn1.FileExists( ) ) return( FALSE );
+  if( !ofn1.IsOk( ) || !ofn1.FileExists( ) ) return( false );
 
   // Look for the gnetlist log file
   os1 = ofn1.GetPath( ) + wxT("/gnetlist.log");
@@ -571,7 +592,7 @@ bool  FileTasks::bDelTmpFiles( void )
     if( m_poFrmMain!=NULL && m_poFrmMain->IsShown( ) )
     {
       // Prompt the user
-      if( liTmpFileMgt == (long) eTFMS_PROMPT )
+      if( liTmpFileMgt == (long) eTFM_PROMPT )
       {
         os1 = wxT("Delete Temporary Files");
         os2 = wxT("\nDelete the following temporary files :\n\n");
@@ -588,74 +609,82 @@ bool  FileTasks::bDelTmpFiles( void )
     }
   }
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
-// Open and load a circuit description (netlist) file into the m_poFrmMain
-// attribute's simulation objects.
+//**************************************************************************************************
+// Open and load a circuit description (netlist) file into the m_poFrmMain attribute's simulation
+// objects.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bOpen( void )
 {
-  bool  bRtn=TRUE;
+  bool      bRtn=true;
+  wxString  os1;
 
   // Attempt to load the circuit description file
-  if(      m_poFrmMain->m_oSimnNgs.bLoadFile( ) )
-    m_poFrmMain->m_oSimnGcp = m_poFrmMain->m_oSimnNgs;
-  else if( m_poFrmMain->m_oSimnGcp.bLoadFile( ) )
-    m_poFrmMain->m_oSimnNgs = m_poFrmMain->m_oSimnGcp;
+  NetList::bLoadFile( );
+
+  // Load circuit description (& simulation) information into the attributes of the class hierarchy
+  if(      m_poFrmMain->m_oSimnNgSp.bLoad( ) ) m_poFrmMain->m_oSimnGCap = m_poFrmMain->m_oSimnNgSp;
+  else if( m_poFrmMain->m_oSimnGCap.bLoad( ) ) m_poFrmMain->m_oSimnNgSp = m_poFrmMain->m_oSimnGCap;
 
   // Check for problems
   if( ! m_poFrmMain->m_oNetLst.bIsValid( ) )
   {
     DlgErrNetLst( );
     m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_NETLIST );
-    bRtn = FALSE;
+    bRtn = false;
   }
   else
-    m_poFrmMain->SetStatusText( wxT(" Netlist file opened successfully"),
-                                FrmMain::ePANE_MESG );
+    m_poFrmMain->SetStatusText( wxT(" Netlist file opened successfully"), FrmMain::ePANE_MESAGE );
 
   // Set the main frame title and the schematic file name/s if supplied
   bSetTitle( );
-  bSetSchemFiles( m_poFrmMain->m_oNetLst.rosGetSchemFiles( ) );
+  os1 = m_poFrmMain->m_oNetLst.rosGetSchemFiles( );
+  if( ! os1.IsEmpty( ) ) bSetSchemFiles( os1 );
 
   return( bRtn );
 }
 
-//*****************************************************************************
-// Import a schematic file by converting it to a netlist using gNetList and
-// then loading it into the FrmMain simulation object.
+//**************************************************************************************************
+// Import a schematic file by converting it to a netlist using gNetList and then loading it into the
+// FrmMain simulation object.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bImport( void )
 {
-  bool  bRtn=TRUE;
+  bool  bRtn=true;
 
-  // Check that gNetList binary exists and is accessible
-  if( ! bIsOk_gnetlist( ) ) return( FALSE );
+  // Check that gnetList binary exists and is accessible
+  if( ! bIsOk_gnetlist( ) ) return( false );
 
   // Convert the schematic file/s to a netlist file and load it
   if( bExecImport( ) )
   {
-    bSetNetLstFile( m_oPrcGNetList.roGetNetLstFile( ).GetFullPath( ) );
-    m_poFrmMain->m_oSimnNgs.bLoadFile( );
-    m_poFrmMain->m_oSimnGcp.bLoadFile( );
+    bSetNetLstFile( m_oPrcGNetList.rofnGetNetLstFile( ).GetFullPath( ) );
+
+    // Attempt to load the circuit description file
+    NetList::bLoadFile( );
+
+    // Load circuit description (& simulation) info. into the attributes of the class hierarchy
+    m_poFrmMain->m_oSimnNgSp.bLoad( );
+    m_poFrmMain->m_oSimnGCap.bLoad( );
+
     if( m_poFrmMain->m_oNetLst.bIsValid( ) )
       m_poFrmMain->SetStatusText( wxT(" Schematic file/s imported successfully"),
-                                  FrmMain::ePANE_MESG );
+                                  FrmMain::ePANE_MESAGE );
     else
     {
       DlgErrNetLst( );
       m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_NETLIST );
-      bRtn = FALSE;
+      bRtn = false;
     }
   }
   else
@@ -663,7 +692,7 @@ bool  FileTasks::bImport( void )
     DlgErrSchems( );
     m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_CONSOLE );
     m_poFrmMain->m_oNbkTxtCtls.bSetPosn( -1 );
-    bRtn = FALSE;
+    bRtn = false;
   }
 
   // Set the main frame title
@@ -672,12 +701,12 @@ bool  FileTasks::bImport( void )
   return( bRtn );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Reload a simulation object whether it be from a schematic or netlist file.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bReload( void )
 {
@@ -692,43 +721,40 @@ bool  FileTasks::bReload( void )
     bRtn = bImport( );
     if( bRtn )
       m_poFrmMain->SetStatusText( wxT(" Schematic file/s re-imported successfully"),
-                                  FrmMain::ePANE_MESG );
+                                  FrmMain::ePANE_MESAGE );
   }
-  else if( m_oPrcGNetList.roGetNetLstFile( ).IsOk( ) )
+  else if( m_oPrcGNetList.rofnGetNetLstFile( ).IsOk( ) )
   { // Reload a netlist file
     bRtn = bOpen( );
     if( bRtn )
       m_poFrmMain->SetStatusText( wxT(" Netlist file reloaded successfully"),
-                                  FrmMain::ePANE_MESG );
+                                  FrmMain::ePANE_MESAGE );
   }
   else
   {
     // There's no open schematic or netlist to reload, display an error message
-    m_poFrmMain->DlgErrMsg( wxT("Reload Operation Error"),
-                            wxT("No file is currently open.") );
-    bRtn = FALSE;
+    m_poFrmMain->DlgErrMsg( wxT("Reload Operation Error"), wxT("No file is currently open.") );
+    bRtn = false;
   }
 
   return( bRtn );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Close the circuit description file.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bClose( void )
 {
   // Is there a file currently open?
-  if( m_oPrcGNetList.roaGetSchemFiles( ).IsEmpty( ) &&
-      ! m_oPrcGNetList.roGetNetLstFile( ).IsOk( ) )
+  if( m_oPrcGNetList.roaGetSchemFiles().IsEmpty() && !m_oPrcGNetList.rofnGetNetLstFile().IsOk() )
   {
     // There's no open schematic or netlist to close, display an error message
-    m_poFrmMain->DlgErrMsg( wxT("Close Operation Error"),
-                            wxT("No file is currently open.") );
-    return( FALSE );
+    m_poFrmMain->DlgErrMsg( wxT("Close Operation Error"), wxT("No file is currently open.") );
+    return( false );
   }
 
   // Delete temporary files
@@ -740,28 +766,27 @@ bool  FileTasks::bClose( void )
   bSetSchemFiles( wxT("") );
 
   // Set the status bar message
-  m_poFrmMain->SetStatusText( wxT(" Netlist file closed successfully"),
-                              FrmMain::ePANE_MESG );
+  m_poFrmMain->SetStatusText( wxT(" Netlist file closed successfully"), FrmMain::ePANE_MESAGE );
 
   // Set the text control notebook page
   m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_CONSOLE );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Do the necessary tasks before the application exits.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  FileTasks::bExit( void )
 {
   // Delete temporary file/s
-  if( ! bDelTmpFiles( ) ) return( FALSE );
+  if( ! bDelTmpFiles( ) ) return( false );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
