@@ -1,38 +1,36 @@
-//*****************************************************************************
-//                                NbkTxtCtls.cpp                              *
-//                               ----------------                             *
-// Started     : 14/06/2005                                                   *
-// Last Update : 01/07/2011                                                   *
-// Copyright   : (C) 2005 by MSWaters                                         *
-// Email       : M.Waters@bom.gov.au                                          *
-//*****************************************************************************
+//**************************************************************************************************
+//                                         NbkTxtCtls.cpp                                          *
+//                                        ----------------                                         *
+// Started     : 2005-06-14                                                                        *
+// Last Update : 2015-04-01                                                                        *
+// Copyright   : (C) 2005 by MSWaters                                                              *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
-#include "main/NbkTxtCtls.hpp"
+#include "NbkTxtCtls.hpp"
 
-//*****************************************************************************
+//**************************************************************************************************
 // Constructor.
 
 NbkTxtCtls::NbkTxtCtls( void ) : wxNotebook( )
 {
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Destructor.
 
 NbkTxtCtls::~NbkTxtCtls( )
 {
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Create an instantance of this object.
 //
 // Argument List :
@@ -42,81 +40,81 @@ NbkTxtCtls::~NbkTxtCtls( )
 //   roSize - The size
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  NbkTxtCtls::bCreate( wxWindow * poWin, wxWindowID oWinID )
 {
-  bool      bRtn=TRUE;
+  bool      bRtn=true;
   wxString  os1;
 
   // Check if the object has already been created
-  if( bIsCreated( ) )             return( TRUE );
+  if( bIsCreated( ) )             return( true );
 
   // Create the notebook object to hold the text controls
-  if( ! Create( poWin, oWinID ) ) return( FALSE );
+  if( ! Create( poWin, oWinID ) ) return( false );
 
   // Allocate memory for the text controls
   TextCtrl * poTxcConsole = new TextCtrl;
   TextCtrl * poTxcNetList = new TextCtrl;
   TextCtrl * poTxcSimultn = new TextCtrl;
-  TextCtrl * poTxcGnuCap  = new TextCtrl;
   TextCtrl * poTxcNgSpice = new TextCtrl;
+  TextCtrl * poTxcGnuCap  = new TextCtrl;
 
   // Create the text controls
-  if( ! poTxcConsole->bCreate( this ) ) bRtn = FALSE;
-  if( ! poTxcNetList->bCreate( this ) ) bRtn = FALSE;
-  if( ! poTxcSimultn->bCreate( this ) ) bRtn = FALSE;
-  if( ! poTxcGnuCap ->bCreate( this ) ) bRtn = FALSE;
-  if( ! poTxcNgSpice->bCreate( this ) ) bRtn = FALSE;
+  if( ! poTxcConsole->bCreate( this ) ) bRtn = false;
+  if( ! poTxcNetList->bCreate( this ) ) bRtn = false;
+  if( ! poTxcSimultn->bCreate( this ) ) bRtn = false;
+  if( ! poTxcNgSpice->bCreate( this ) ) bRtn = false;
+  if( ! poTxcGnuCap ->bCreate( this ) ) bRtn = false;
 
   // Initialize the text controls
   os1 = wxT("No console I/O to display");
-  if( ! poTxcConsole->bSetInitMsg( os1 ) ) bRtn = FALSE;
+  if( ! poTxcConsole->bSetInitMsg( os1 ) ) bRtn = false;
   os1 = wxT("No netlist currently loaded");
-  if( ! poTxcNetList->bSetInitMsg( os1 ) ) bRtn = FALSE;
+  if( ! poTxcNetList->bSetInitMsg( os1 ) ) bRtn = false;
   os1 = wxT("No simulation currently defined");
-  if( ! poTxcSimultn->bSetInitMsg( os1 ) ) bRtn = FALSE;
-  os1 = wxT("No GNU-Cap simulation results to display");
-  if( ! poTxcGnuCap ->bSetInitMsg( os1 ) ) bRtn = FALSE;
+  if( ! poTxcSimultn->bSetInitMsg( os1 ) ) bRtn = false;
   os1 = wxT("No NG-Spice simulation results to display");
-  if( ! poTxcNgSpice->bSetInitMsg( os1 ) ) bRtn = FALSE;
+  if( ! poTxcNgSpice->bSetInitMsg( os1 ) ) bRtn = false;
+  os1 = wxT("No GNU-Cap simulation results to display");
+  if( ! poTxcGnuCap ->bSetInitMsg( os1 ) ) bRtn = false;
 
   // Define tool tips for the wxNotebook and each page
   poTxcConsole->SetToolTip( wxT("Console I/O (non-editable)") );
   poTxcNetList->SetToolTip( wxT("Netlist file (non-editable)") );
   poTxcSimultn->SetToolTip( wxT("Simulation file (editable)") );
-  poTxcGnuCap ->SetToolTip( wxT("GNU-Cap simulation results (non-editable)") );
   poTxcNgSpice->SetToolTip( wxT("NG-Spice simulation results (non-editable)") );
+  poTxcGnuCap ->SetToolTip( wxT("GNU-Cap simulation results (non-editable)") );
 
   // Add the display objects to the wxNotebook (wxNotebook will delete them)
   AddPage( poTxcConsole, wxT("   Console   ")  );
   AddPage( poTxcNetList, wxT("   NetList    ") );
   AddPage( poTxcSimultn, wxT(" Simulation ")   );
-  AddPage( poTxcGnuCap,  wxT("  GNU-Cap   ")   );
-  AddPage( poTxcNgSpice, wxT("  NG-Spice  ")   );
+  AddPage( poTxcNgSpice, wxT("  NG-Spice   ")  );
+  AddPage( poTxcGnuCap , wxT("  GNU-Cap   ")   );
 
   bInitialize( );
 
   return( bRtn );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Clear one or all text controls associated with the notebook.
 //
 // Argument List :
 //   ePage - The enumerated page identifier
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  NbkTxtCtls::bClear( ePageType ePage )
 {
   size_t  szt1;
 
   // Check that the object has been created
-  if( ! bIsCreated( ) ) return( FALSE );
+  if( ! bIsCreated( ) ) return( false );
 
   // Attempt the clear operation
   switch( ePage )
@@ -124,42 +122,42 @@ bool  NbkTxtCtls::bClear( ePageType ePage )
     case ePAGE_CONSOLE :  // Clear a particular page
     case ePAGE_NETLIST :
     case ePAGE_SIMULTN :
-    case ePAGE_GNUCAP  :
     case ePAGE_NGSPICE :
+    case ePAGE_GNUCAP  :
     case ePAGE_CURRENT :
       if( ! poGetPage( ePage )->bClear( ) )
-        return( FALSE );
+        return( false );
       break;
 
     case ePAGE_ALL :      // Clear all pages
       for( szt1=0; szt1<GetPageCount( ); szt1++ )
         if( ! poGetPage( (ePageType) szt1 )->bClear( ) )
-          return( FALSE );
+          return( false );
       break;
 
      default :            // Invalid page identifier
-       return( FALSE );
+       return( false );
   }
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Initialize one or all text controls associated with the notebook.
 //
 // Argument List :
 //   ePage - The enumerated page identifier
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  NbkTxtCtls::bInitialize( ePageType ePage )
 {
   size_t  szt1;
 
   // Check that the object has been created
-  if( ! bIsCreated( ) ) return( FALSE );
+  if( ! bIsCreated( ) ) return( false );
 
   // Attempt the initialize operation
   switch( ePage )
@@ -167,79 +165,79 @@ bool  NbkTxtCtls::bInitialize( ePageType ePage )
     case ePAGE_CONSOLE :  // Initialize a particular page
     case ePAGE_NETLIST :
     case ePAGE_SIMULTN :
-    case ePAGE_GNUCAP  :
     case ePAGE_NGSPICE :
+    case ePAGE_GNUCAP  :
     case ePAGE_CURRENT :
       if( ! poGetPage( ePage )->bInitialize( ) )
-        return( FALSE );
+        return( false );
       break;
 
     case ePAGE_ALL :      // Initialize all pages
       for( szt1=0; szt1<GetPageCount( ); szt1++ )
         if( ! poGetPage( (ePageType) szt1 )->bInitialize( ) )
-          return( FALSE );
+          return( false );
       break;
 
      default :            // Invalid page identifier
-       return( FALSE );
+       return( false );
   }
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Set the page to be displayed.
 //
 // Argument List :
 //   ePage - The enumerated page identifier
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  NbkTxtCtls::bSetPage( NbkTxtCtls::ePageType ePage )
 {
   // Check if the object has already been created
-  if( ! bIsCreated( ) )                        return( FALSE );
+  if( ! bIsCreated( ) )                        return( false );
 
   // Check that the page identifier is valid
-  if( GetPageCount( ) < ((size_t) ePage + 1) ) return( FALSE );
+  if( GetPageCount( ) < ((size_t) ePage + 1) ) return( false );
 
   SetSelection( (size_t) ePage );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Set the insert and show positions in the currently displayed page.
 //
 // Argument List :
 //   liPosn - The position
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  NbkTxtCtls::bSetPosn( long liPosn )
 {
   TextCtrl * poTxtCtl;
 
   // Check if the object has already been created
-  if( ! bIsCreated( ) )  return( FALSE );
+  if( ! bIsCreated( ) )  return( false );
 
   // Get a pointer to the currently displayed page
   poTxtCtl = (TextCtrl *) GetCurrentPage( );
 
-  if( poTxtCtl == NULL ) return( FALSE );
+  if( poTxtCtl == NULL ) return( false );
 
   // Set the position
   if( liPosn >= 0 ) poTxtCtl->SetInsertionPoint( liPosn );
   else              poTxtCtl->SetInsertionPointEnd( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Get the enumerated identifier for the currently displayed notebook page.
 //
 // Return Values :
@@ -259,15 +257,15 @@ NbkTxtCtls::ePageType  NbkTxtCtls::eGetPage( void )
     case 0  : ePage = ePAGE_CONSOLE; break;
     case 1  : ePage = ePAGE_NETLIST; break;
     case 2  : ePage = ePAGE_SIMULTN; break;
-    case 3  : ePage = ePAGE_GNUCAP;  break;
-    case 4  : ePage = ePAGE_NGSPICE; break;
+    case 3  : ePage = ePAGE_NGSPICE; break;
+    case 4  : ePage = ePAGE_GNUCAP;  break;
     default : ePage = ePAGE_NONE;
   }
 
   return( ePage );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Get a pointer to the text control currently being displayed.
 //
 // Argument List :
@@ -290,4 +288,4 @@ TextCtrl * NbkTxtCtls::poGetPage( NbkTxtCtls::ePageType ePage )
   return( (TextCtrl *) GetPage( (size_t) ePage ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
