@@ -1,24 +1,22 @@
-//*****************************************************************************
-//                               SimnGnuCap.cpp                               *
-//                              ----------------                              *
-// Started     : 07/05/2008                                                   *
-// Last Update : 25/05/2011                                                   *
-// Copyright   : (C) 2008 by MSWaters                                         *
-// Email       : M.Waters@bom.gov.au                                          *
-//*****************************************************************************
+//**************************************************************************************************
+//                                         SimnGnuCap.cpp                                          *
+//                                        ----------------                                         *
+// Started     : 2008-05-07                                                                        *
+// Last Update : 2015-04-09                                                                        *
+// Copyright   : (C) 2008 by MSWaters                                                              *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
-#include "netlist/SimnGnuCap.hpp"
+#include "SimnGnuCap.hpp"
 
-//*****************************************************************************
+//**************************************************************************************************
 // Constructor.
 
 SimnGnuCap::SimnGnuCap( void ) : SimnBase( )
@@ -29,19 +27,19 @@ SimnGnuCap::SimnGnuCap( void ) : SimnBase( )
   bClear( );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Destructor.
 
 SimnGnuCap::~SimnGnuCap( )
 {
 }
 
-//*****************************************************************************
-// Extract the simulator engine and return TRUE if it's GNU-Cap.
+//**************************************************************************************************
+// Extract the simulator engine and return true if it's GNU-Cap.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  SimnGnuCap::bLoadSimEng( void )
 {
@@ -53,13 +51,13 @@ bool  SimnGnuCap::bLoadSimEng( void )
   {
     os1 = NetList::m_osaNetLst.Item( sz1 );
     if( os1.IsEmpty( ) ) continue;
-    if( os1.Upper( ).Contains( wxT("GNU-CAP") ) ) return( TRUE );
+    if( os1.Upper( ).Contains( wxT("GNU-CAP") ) ) return( true );
   }
 
-  return( FALSE );
+  return( false );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Extract all the simulator command lines from the circuit description.
 // The following commands are currently detected and extracted :
 //
@@ -74,12 +72,12 @@ bool  SimnGnuCap::bLoadSimEng( void )
 //   .GENERATOR
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  SimnGnuCap::bLoadSimCmds( void )
 {
-  bool      bRtn=FALSE;
+  bool      bRtn=false;
   wxString  os1;
   size_t    sz1;
 
@@ -111,18 +109,42 @@ bool  SimnGnuCap::bLoadSimCmds( void )
       m_oCmdPR.bSetString( NetList::m_osaNetLst.Item( sz1 ) );
     else                               continue;
 
-    bRtn = TRUE;
+    bRtn = true;
   }
 
   return( bRtn );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
+// Extract the source component.
+//
+// Return Values :
+//   true  - Success
+//   false - Failure
+
+bool  SimnGnuCap::bLoadSigSrc( void )
+{
+  // Search for and extract a signal source component
+  if( SimnBase::bLoadSigSrc( ) )
+    return( true );
+
+  // Special treatment for a DC Signal Source
+  if( eGetAnaType( ) == eCMD_DC )
+  {
+    m_oCpntSwpSrc.bClear( );
+    m_oCpntSwpSrc.bSetName( m_oCmdDC.m_osSource );
+    return( true );
+  }
+
+  return( false );
+}
+
+//**************************************************************************************************
 // Clear all object attributes.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  SimnGnuCap::bClear( void )
 {
@@ -133,12 +155,12 @@ bool  SimnGnuCap::bClear( void )
   return( SimnBase::bClear( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Clear all simulator command objects.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  SimnGnuCap::bClrCmds( void )
 {
@@ -151,30 +173,30 @@ bool  SimnGnuCap::bClrCmds( void )
   m_oCmdPR .bSetDefaults( );
   m_oCmdGEN.bSetDefaults( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Clear all test points ie. nodes and components.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  SimnGnuCap::bClrTstPts( void )
 {
   m_oCmdPR.m_osaNodes.Empty( );
   m_oCmdPR.m_osaCpnts.Empty( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Do the current simulation settings constitute a valid simulation?
 //
 // Return Values :
-//   TRUE  - Valid
-//   FALSE - Not valid
+//   true  - Valid
+//   false - Not valid
 
 bool  SimnGnuCap::bValidate( void )
 {
@@ -214,118 +236,98 @@ bool  SimnGnuCap::bValidate( void )
   return( bIsValid( ) );
 }
 
-//*****************************************************************************
-// Load a simulation to file.
-//
-// Argument List :
-//   rosFName - The name of the file to be loaded
+//**************************************************************************************************
+// Load the simulation information from the netlist string array into the object attributes.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
-bool  SimnGnuCap::bLoadFile( const wxString & rosFName )
+bool  SimnGnuCap::bLoad( void )
 {
   // Envoke the base class load operations
-  return( SimnBase::bLoadFile( rosFName ) );
+  return( SimnBase::bLoad( ) );
 }
 
-//*****************************************************************************
-// Save (or resave) a simulation to file.
-//
-// Argument List :
-//   rosFName - The name of the file to be saved
+//**************************************************************************************************
+// Save the simulation information to the netlist string array from the object attributes.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
-bool  SimnGnuCap::bSaveFile( const wxString & rosFName )
+bool  SimnGnuCap::bSave( void )
 {
-  wxString  os1;
-
-  // Save the netlist to file
-  if( ! SimnBase::bSaveFile( rosFName ) ) return( FALSE );
-
-  // Open the file
-  wxTextFile  oFileCct( m_ofnSaveFile.GetFullPath( ) );
-  if( ! oFileCct.Open( ) )               return( FALSE );
-
-  // Temporarily remove the circuit description terminator ie. ".END"
-  oFileCct.RemoveLine( oFileCct.GetLineCount( )-1 );
+  // Envoke the base class save operations
+  if( ! SimnBase::bSave( ) ) return( false );
 
   // Append the simulation command lines to the end of the file
-  oFileCct.AddLine( wxT("* GNU-Cap Simulation Commands") );
-  oFileCct.AddLine( m_oCmdOPT );
-  oFileCct.AddLine( m_oCmdPR );
-  if( m_oCmdGEN.bIsValid( ) ) oFileCct.AddLine( m_oCmdGEN );
-  if( m_oCmdOP .bIsValid( ) ) oFileCct.AddLine( m_oCmdOP  );
-  if( m_oCmdDC .bIsValid( ) ) oFileCct.AddLine( m_oCmdDC  );
-  if( m_oCmdAC .bIsValid( ) ) oFileCct.AddLine( m_oCmdAC  );
-  if( m_oCmdTR .bIsValid( ) ) oFileCct.AddLine( m_oCmdTR  );
-  if( m_oCmdFO .bIsValid( ) ) oFileCct.AddLine( m_oCmdFO  );
-  oFileCct.AddLine( wxT("") );
+  NetList::m_osaNetLst.Last( ) = wxT("* GNU-Cap Simulation Commands");
+  NetList::m_osaNetLst.Add( m_oCmdOPT );
+  NetList::m_osaNetLst.Add( m_oCmdPR );
+  if( m_oCmdGEN.bIsValid( ) ) NetList::m_osaNetLst.Add( m_oCmdGEN );
+  if( m_oCmdOP .bIsValid( ) ) NetList::m_osaNetLst.Add( m_oCmdOP  );
+  if( m_oCmdDC .bIsValid( ) ) NetList::m_osaNetLst.Add( m_oCmdDC  );
+  if( m_oCmdAC .bIsValid( ) ) NetList::m_osaNetLst.Add( m_oCmdAC  );
+  if( m_oCmdTR .bIsValid( ) ) NetList::m_osaNetLst.Add( m_oCmdTR  );
+  if( m_oCmdFO .bIsValid( ) ) NetList::m_osaNetLst.Add( m_oCmdFO  );
+  NetList::m_osaNetLst.Add( wxT("") );
 
   // Add the circuit description terminator
-  oFileCct.AddLine( wxT(".END") );
-  oFileCct.AddLine( wxT("") );
+  NetList::m_osaNetLst.Add( wxT(".END") );
 
-  // Save the changes to disk
-  oFileCct.Write( );
-  oFileCct.Close( );
-
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Add a node to the list of test points.
 //
 // Argument List :
 //   rosName - The name of the node to be added to the list of test points
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  SimnGnuCap::bAddTstNode( const wxString & rosName )
 {
   // Is the node name valid?
-  if( rosName.IsEmpty( ) )                                 return( FALSE );
+  if( rosName.IsEmpty( ) )                                 return( false );
   // Is the node name already in the test node list?
-  if( rosaGetTstNodes( ).Index( rosName ) != wxNOT_FOUND ) return( TRUE );
+  if( rosaGetTstNodes( ).Index( rosName ) != wxNOT_FOUND ) return( true );
 
   // Add the node name to the list of test points
   m_oCmdPR.m_osaNodes.Add( rosName );
   m_oCmdPR.m_osaNodes.Sort( &iStrCmpNode );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Add a component to the list of test points.
 //
 // Argument List :
 //   rosName - The name of the component to be added to the list of test points
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  SimnGnuCap::bAddTstCpnt( const wxString & rosName )
 {
   // Is the component name valid?
-  if( rosName.IsEmpty( ) )                                 return( FALSE );
+  if( rosName.IsEmpty( ) )                                 return( false );
   // Is the component name already in the test component list?
-  if( rosaGetTstCpnts( ).Index( rosName ) != wxNOT_FOUND ) return( TRUE );
+  if( rosaGetTstCpnts( ).Index( rosName ) != wxNOT_FOUND ) return( true );
 
   // Add the component name to the list of test points
   m_oCmdPR.m_osaCpnts.Add( rosName );
   m_oCmdPR.m_osaCpnts.Sort( &iStrCmpCpnt );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Copy the contents of a SimnNgSpice object.
 //
 // Argument List :
@@ -371,7 +373,7 @@ SimnGnuCap & SimnGnuCap::operator = ( const SimnNgSpice & roSimn )
   return( *this );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Print the object attributes.
 //
 // Argument List :
@@ -379,15 +381,16 @@ SimnGnuCap & SimnGnuCap::operator = ( const SimnNgSpice & roSimn )
 
 void  SimnGnuCap::Print( const wxString & rosPrefix )
 {
-  SimnBase::Print( rosPrefix + wxT("SimnBase::")  );
-  m_oCmdOPT.Print( rosPrefix + wxT("m_oCmdOPT::") );
-  m_oCmdOP .Print( rosPrefix + wxT("m_oCmdOP::")  );
-  m_oCmdDC .Print( rosPrefix + wxT("m_oCmdDC::")  );
-  m_oCmdAC .Print( rosPrefix + wxT("m_oCmdAC::")  );
-  m_oCmdTR .Print( rosPrefix + wxT("m_oCmdTR::")  );
-  m_oCmdFO .Print( rosPrefix + wxT("m_oCmdFO::")  );
-  m_oCmdPR .Print( rosPrefix + wxT("m_oCmdPR::")  );
-  m_oCmdGEN.Print( rosPrefix + wxT("m_oCmdGEN::") );
+  SimnBase::Print( rosPrefix + wxT("SimnBase::") );
+
+  m_oCmdOPT.Print( rosPrefix + wxT("m_oCmdOPT.") );
+  m_oCmdOP .Print( rosPrefix + wxT("m_oCmdOP.")  );
+  m_oCmdDC .Print( rosPrefix + wxT("m_oCmdDC.")  );
+  m_oCmdAC .Print( rosPrefix + wxT("m_oCmdAC.")  );
+  m_oCmdTR .Print( rosPrefix + wxT("m_oCmdTR.")  );
+  m_oCmdFO .Print( rosPrefix + wxT("m_oCmdFO.")  );
+  m_oCmdPR .Print( rosPrefix + wxT("m_oCmdPR.")  );
+  m_oCmdGEN.Print( rosPrefix + wxT("m_oCmdGEN.") );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
