@@ -1,24 +1,22 @@
-//*****************************************************************************
-//                              CmdNgSpiceTR.cpp                              *
-//                             ------------------                             *
-// Started     : 15/10/2007                                                   *
-// Last Update : 12/08/2011                                                   *
-// Copyright   : (C) 2007 by M.S.Waters                                       *
-// Email       : M.Waters@bom.gov.au                                          *
-//*****************************************************************************
+//**************************************************************************************************
+//                                        CmdNgSpiceTR.cpp                                         *
+//                                       ------------------                                        *
+// Started     : 2007-10-15                                                                        *
+// Last Update : 2014-12-12                                                                        *
+// Copyright   : (C) 2007 by MSWaters                                                              *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
-#include "ngspice/commands/CmdNgSpiceTR.hpp"
+#include "CmdNgSpiceTR.hpp"
 
-//*****************************************************************************
+//**************************************************************************************************
 // Constructor.
 
 CmdNgSpiceTR::CmdNgSpiceTR( void )
@@ -26,19 +24,19 @@ CmdNgSpiceTR::CmdNgSpiceTR( void )
   bSetDefaults( );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Destructor.
 
 CmdNgSpiceTR::~CmdNgSpiceTR( )
 {
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Check that the object attributes are valid.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdNgSpiceTR::bValidate( void )
 {
@@ -47,35 +45,30 @@ bool  CmdNgSpiceTR::bValidate( void )
   CmdBase::bValidate( );
 
   // Check the sweep start and stop values
-  if( ! ConvertType::bStrToDFlt( m_osStart, &df1 ) )
-    SetErrMsg( wxT("Invalid sweep start value.") );
-  if( ! ConvertType::bStrToDFlt( m_osStop,  &df2 ) )
-    SetErrMsg( wxT("Invalid sweep stop value.") );
-  if( df2 < df1 )
-    SetErrMsg( wxT("Start value greater than stop value.") );
+  if( ! CnvtType::bStrToFlt( m_osStart, &df1 ) ) SetErrMsg( wxT("Invalid sweep start value.") );
+  if( ! CnvtType::bStrToFlt( m_osStop,  &df2 ) ) SetErrMsg( wxT("Invalid sweep stop value.") );
+  if( df2 < df1 )                                SetErrMsg( wxT("Start value greater than stop value.") );
 
   // Check the sweep step value and initial conditions
-  if( ! ConvertType::bStrToDFlt( m_osStep, &df3 ) )
-    SetErrMsg( wxT("Invalid sweep step value.") );
-  if( df3 <= 0.0 )
-    SetErrMsg( wxT("Step value less than or equal to zero.") );
+  if( ! CnvtType::bStrToFlt( m_osStep, &df3 ) )  SetErrMsg( wxT("Invalid sweep step value.") );
+  if( df3 <= 0.0 )                               SetErrMsg( wxT("Step value less than or equal to zero.") );
   switch( m_eInitC )
   {
     case eINITC_WARM :
     case eINITC_UICS :
     case eINITC_COLD : break;
-    default          : SetErrMsg( wxT("Invalid initial conditions value.") );
+    default          :                           SetErrMsg( wxT("Invalid initial conditions value.") );
   }
 
   return( bIsValid( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Set the object attributes to they're default values.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdNgSpiceTR::bSetDefaults( void )
 {
@@ -90,10 +83,10 @@ bool  CmdNgSpiceTR::bSetDefaults( void )
 
   m_eInitC = eINITC_WARM;
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Parse the command string.
 //
 // Eg.s : .TRAN 10.00m 100.00m 0.00 10.00m UIC
@@ -102,8 +95,8 @@ bool  CmdNgSpiceTR::bSetDefaults( void )
 //        .TRAN 10.00m 100.00m
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdNgSpiceTR::bParse( void )
 {
@@ -128,12 +121,12 @@ bool  CmdNgSpiceTR::bParse( void )
 
   // Extract the step increment (must be present)
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) )   m_osStep  = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) )   m_osStep  = os1;
   else                    return( bValidate( ) );
 
   // Extract the stop value (must be present)
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) )   m_osStop  = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) )   m_osStop  = os1;
   else                    return( bValidate( ) );
 
   // Extract the start value (may be omitted)
@@ -141,7 +134,7 @@ bool  CmdNgSpiceTR::bParse( void )
   if( ostk1.HasMoreTokens( ) )
   {
     os1 = ostk1.GetNextToken( );
-    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStart = os1;
+    if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStart = os1;
     else                  return( bValidate( ) );
   }
 
@@ -160,12 +153,12 @@ bool  CmdNgSpiceTR::bParse( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Format the command string.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdNgSpiceTR::bFormat( void )
 {
@@ -187,7 +180,7 @@ bool  CmdNgSpiceTR::bFormat( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Copy the contents of a CmdGnuCapAC object.
 //
 // Argument List :
@@ -210,7 +203,7 @@ CmdNgSpiceTR & CmdNgSpiceTR::operator = ( const CmdGnuCapTR & roCmdTR )
   return( *this );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Print the object attributes.
 //
 // Argument List :
@@ -220,43 +213,34 @@ void  CmdNgSpiceTR::Print( const wxString & rosPrefix )
 {
   CmdBase::Print( rosPrefix + wxT("CmdBase::") );
 
-  cout << rosPrefix.mb_str( ) << "m_osStart : "
-       << m_osStart.mb_str( ) << '\n';
-  cout << rosPrefix.mb_str( ) << "m_osStop  : "
-       << m_osStop .mb_str( ) << '\n';
-  cout << rosPrefix.mb_str( ) << "m_osStep  : "
-       << m_osStep .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStart : " << m_osStart.mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStop  : " << m_osStop .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStep  : " << m_osStep .mb_str( ) << '\n';
 
-  cout << rosPrefix.mb_str( ) << "m_eInitC  : ";
+  std::cout << rosPrefix.mb_str( ) << "m_eInitC  : ";
   switch( m_eInitC )
   {
-    case eINITC_WARM : cout << "eINITC_COLD\n"; break;
-    case eINITC_UICS : cout << "eINITC_UICS\n"; break;
-    case eINITC_COLD : cout << "eINITC_COLD\n"; break;
-    case eINITC_NONE : cout << "eINITC_NONE\n"; break;
-    default :          cout << "Invalid\n";     break;
+    case eINITC_WARM : std::cout << "eINITC_COLD\n"; break;
+    case eINITC_UICS : std::cout << "eINITC_UICS\n"; break;
+    case eINITC_COLD : std::cout << "eINITC_COLD\n"; break;
+    case eINITC_NONE : std::cout << "eINITC_NONE\n"; break;
+    default :          std::cout << "Invalid\n";     break;
   }
 }
 
-//*****************************************************************************
-//                                                                            *
-//                                 Test Utility                               *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                          Test Utility                                           *
+//**************************************************************************************************
 
-#ifdef TEST_CMDNGSTR
-
-// System include files
-
-
-// Application includes
+#ifdef TEST_CMDNGSPICETR
 
+using  namespace  std;
 
 // Function prototypes
 
 void  Usage( char * psAppName );
 
-//*****************************************************************************
+//**************************************************************************************************
 
 int  main( int argc, char * argv[ ] )
 {
@@ -307,7 +291,7 @@ int  main( int argc, char * argv[ ] )
   exit( EXIT_SUCCESS );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 
 void  Usage( char * psAppName )
 {
@@ -316,6 +300,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_CMDNGSTR
+#endif // TEST_CMDNGSPICETR
 
-//*****************************************************************************
+//**************************************************************************************************
