@@ -1,57 +1,45 @@
-//*****************************************************************************
-//                             DlgNgsCfgSrc.hpp                               *
-//                            ------------------                              *
-// Description : This dialogue is used to enter values associated with an     *
-//               NG-Spice independent voltage source definition. It is used   *
-//               for Transient analysis and is based on a pulse function.     *
-// Started     : 10/05/2005                                                   *
-// Last Update : 21/05/2009                                                   *
-// Copyright   : (C) 2005 by M.S.Waters                                       *
-// Email       : M.Waters@bom.gov.au                                          *
-//*****************************************************************************
+//**************************************************************************************************
+//                                        DlgNgsCfgSrc.hpp                                         *
+//                                       ------------------                                        *
+// Description : This dialogue is used to enter values associated with an NG-Spice independent     *
+//               voltage source definition. It is used for Transient analysis and is based on a    *
+//               pulse function.                                                                   *
+// Started     : 2005-05-10                                                                        *
+// Last Update : 2015-04-17                                                                        *
+// Copyright   : (C) 2005 by MSWaters                                                              *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
 #ifndef DLGNGSCFGSRC_HPP
 #define DLGNGSCFGSRC_HPP
 
-// System Includes
-
-using  namespace  std;
-
-#include <iostream>
-#include <climits>
-
-// wxWidgets Includes
-
-#include <wx/wx.h>
-#include <wx/tokenzr.h>
-
 // Application Includes
 
+#include "TypeDefs.hpp"
 #include "utility/PnlValue.hpp"
 #include "netlist/CpntNgsIndSrc.hpp"
 
-// Local Constant Declarations
+// wxWidgets Includes
 
+#include <wx/tokenzr.h>
 
-//*****************************************************************************
+//**************************************************************************************************
 
 class DlgNgsCfgSrc : public wxDialog
 {
   private :
 
     // Value panel controls for a sinusoidal source
-    PnlValue  m_oPnlSinOffset;
     PnlValue  m_oPnlSinAmp;
     PnlValue  m_oPnlSinFreq;
+    PnlValue  m_oPnlSinOffset;
     PnlValue  m_oPnlSinDelay;
     PnlValue  m_oPnlSinDamp;
 
@@ -83,8 +71,8 @@ class DlgNgsCfgSrc : public wxDialog
 
   public :
 
-    DlgNgsCfgSrc( wxWindow * poWin );
-   ~DlgNgsCfgSrc( );
+          DlgNgsCfgSrc( wxWindow * poWin );
+         ~DlgNgsCfgSrc( );
 
     bool  bClear( void );
 
@@ -130,9 +118,9 @@ class DlgNgsCfgSrc : public wxDialog
     };
 
     // Leave this as the last line as private access is envoked by macro
-    DECLARE_EVENT_TABLE( )
+    wxDECLARE_EVENT_TABLE( );
 };
 
-//*****************************************************************************
+//**************************************************************************************************
 
 #endif // DLGNGSCFGSRC_HPP
