@@ -1,57 +1,56 @@
-//*****************************************************************************
-//                               PrcNgSpice.cpp                               *
-//                              ----------------                              *
-//  Started     : 07/05/2004                                                  *
-//  Last Update : 08/07/2011                                                  *
-//  Copyright   : (C) 2004 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
-//*****************************************************************************
+//**************************************************************************************************
+//                                         PrcNgSpice.cpp                                          *
+//                                        ----------------                                         *
+// Started     : 2004-05-07                                                                        *
+// Last Update : 2015-03-20                                                                        *
+// Copyright   : (C) 2004 by MSWaters                                                              *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
-#include "process/PrcNgSpice.hpp"
+#include "PrcNgSpice.hpp"
 
-//*****************************************************************************
+//**************************************************************************************************
 // Constructor.
 
-PrcNgSpice::PrcNgSpice( void ) : PrcSimrBase( )
+PrcNgSpice::PrcNgSpice( void ) : PrcSimEngBase( )
 {
   // Set the simulation engine type
   m_eSimEng = eSIMR_NGSPICE;
 
   // Set the simulator binary file name if it can be found
-  bSetBinary( wxT("ngspice") );
+  bSetBinary( BIN_NGSPICE );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Destructor.
 
 PrcNgSpice::~PrcNgSpice( )
 {
 }
 
-//*****************************************************************************
-// Match a component to a set of node labels. Component voltages cannot be
-// specified using the component label in the NG-Spice print statement. The two
-// node labels connected to the component must be specified. When parsing the
-// print statement the component label must be derived from the node labels.
-// This may not work where components are connected in parallel. The nodes are
-// specified in the form "<Node1>,<Node2>" eg. "1,2".
+//**************************************************************************************************
+// Match a component to a set of node labels.
+//
+// Component voltages cannot be specified using the component label in the NG-Spice print statement.
+// The two node labels connected to the component must be specified. When parsing the print
+// statement the component label must be derived from the node labels. This may not work where
+// components are connected in parallel. The nodes are specified in the form "<Node1>,<Node2>"
+// eg. "1,2".
 //
 // Argument List :
 //   roSimn     - The simulation object
 //   rosToNodes - The nodes to match, also used to return the component label
 //
 // Return Values :
-//   TRUE  - Success (a component with the specified nodes was found)
-//   FALSE - Failure
+//   true  - Success (a component with the specified nodes was found)
+//   false - Failure
 
 bool  PrcNgSpice::bMatchCpnt( SimnNgSpice & roSimn, wxString & rosToNodes )
 {
@@ -61,9 +60,9 @@ bool  PrcNgSpice::bMatchCpnt( SimnNgSpice & roSimn, wxString & rosToNodes )
   size_t         sz1;
 
   // Argument validity checks
-  if( rosToNodes.IsEmpty( ) )             return( FALSE );
-  if( roSimn.m_oaCpnts.GetCount( ) <= 0 ) return( FALSE );
-  if( rosToNodes.Freq( wxT(',') ) != 1 )  return( FALSE );
+  if( rosToNodes.IsEmpty( ) )             return( false );
+  if( roSimn.m_oaCpnts.GetCount( ) <= 0 ) return( false );
+  if( rosToNodes.Freq( wxT(',') ) != 1 )  return( false );
 
   // Extract the node labels
   osaNodes.Add( rosToNodes.BeforeFirst( wxT(',') ) );
@@ -74,18 +73,18 @@ bool  PrcNgSpice::bMatchCpnt( SimnNgSpice & roSimn, wxString & rosToNodes )
   {
     tCpnt = roSimn.m_oaCpnts.Item( sz1 );
     if( ! tCpnt.bParse( ) )            continue;
-    if( tCpnt.m_osaNodes == osaNodes ) break;
+    if( tCpnt.rosaGetNodes( ) == osaNodes ) break;
   }
 
   // Was a match found?
-  if( ! tCpnt.bIsValid( ) )               return( FALSE );
+  if( ! tCpnt.bIsValid( ) )               return( false );
 
-  rosToNodes = tCpnt.m_osName;
+  rosToNodes = tCpnt.rosGetName( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Convert a list of component labels to the corresponding list of node pairs.
 //
 // Argument List :
@@ -102,20 +101,20 @@ void  PrcNgSpice::Convert2Nodes( wxArrayString & rosaCpnts, SimnNgSpice & roSimn
   {
     os1 = rosaCpnts.Item( sz1 );
     tCpnt = roSimn.roGetCpnt( os1 );
-    if( ! tCpnt.bParse( ) )                 continue;
-    if( tCpnt.m_osaNodes.GetCount( ) != 2 ) continue;
+    if( ! tCpnt.bParse( ) )                      continue;
+    if( tCpnt.rosaGetNodes( ).GetCount( ) != 2 ) continue;
     os1.Empty( );
-    os1 << tCpnt.m_osaNodes.Item( 0 ) << wxT(',') << tCpnt.m_osaNodes.Item( 1 );
+    os1 << tCpnt.rosaGetNodes( ).Item( 0 ) << wxT(',') << tCpnt.rosaGetNodes( ).Item( 1 );
     rosaCpnts.Item( sz1 ) = os1;
   }
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Create a WIDTH command based on a PRINT command.
-// By default raw output from NG-Spice uses an 80 column output width which
-// allows about two dependant variables to be displayed. To display more
-// information a .WIDTH statement must be added to increase the number columns
-// in the output.
+//
+// By default raw output from NG-Spice uses an 80 column output width which allows about two
+// dependant variables to be displayed. To display more information a .WIDTH statement must be added
+// to increase the number columns in the output.
 //
 // Argument List :
 //   rosCmdPR - The Print command
@@ -151,13 +150,12 @@ wxString & PrcNgSpice::rosMakeCmdWIDTH( wxString & rosCmdPR )
   return( osCmdWIDTH );
 }
 
-//*****************************************************************************
-// This function is a generic results file formatter which works in most
-// circumstance.
+//**************************************************************************************************
+// This function is a generic results file formatter which works in most circumstance.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  PrcNgSpice::bFmtCommon( void )
 {
@@ -165,7 +163,7 @@ bool  PrcNgSpice::bFmtCommon( void )
   size_t    sz1, sz2;
 
   // This function requires the results file to be open
-  if( ! m_oFileResults.IsOpened( ) ) return( FALSE );
+  if( ! m_oFileResults.IsOpened( ) ) return( false );
 
   // Find the beginning of the data area (ie. the 1st line starting with "Index")
   for( sz1=0; sz1<m_oFileResults.GetLineCount( ); sz1++ )
@@ -176,7 +174,7 @@ bool  PrcNgSpice::bFmtCommon( void )
   if( sz1 >= (m_oFileResults.GetLineCount( )-1) )
   {
     SetErrMsg( wxT("Couldn't find the data section in the results file.") );
-    return( FALSE );
+    return( false );
   }
 
   // Delete everything before the data area
@@ -201,15 +199,15 @@ bool  PrcNgSpice::bFmtCommon( void )
   // Format the data lines
   bFmtDataLines( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Format the column header in the results file.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  PrcNgSpice::bFmtColLabels( void )
 {
@@ -218,11 +216,11 @@ bool  PrcNgSpice::bFmtColLabels( void )
   int  i1;
 
   // This function requires the results file to be open
-  if( ! m_oFileResults.IsOpened( ) ) return( FALSE );
+  if( ! m_oFileResults.IsOpened( ) ) return( false );
 
   // Get the column header line
   ostk1 = m_oFileResults.GetFirstLine( );
-  if( ostk1.CountTokens( ) < 3 )     return( FALSE );
+  if( ostk1.CountTokens( ) < 3 )     return( false );
 
   // Dispose of the first field (ie. "Index")
   ostk1.GetNextToken( );
@@ -252,15 +250,15 @@ bool  PrcNgSpice::bFmtColLabels( void )
 
   m_oFileResults.GetFirstLine( ) = osLine;
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Format a data lines in the results file.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  PrcNgSpice::bFmtDataLines( void )
 {
@@ -271,7 +269,7 @@ bool  PrcNgSpice::bFmtDataLines( void )
   int       i1;
 
   // This function requires the results file to be open
-  if( ! m_oFileResults.IsOpened( ) ) return( FALSE );
+  if( ! m_oFileResults.IsOpened( ) ) return( false );
 
   for( sz1=1; sz1<m_oFileResults.GetLineCount( ); sz1++ )
   {
@@ -280,7 +278,7 @@ bool  PrcNgSpice::bFmtDataLines( void )
 
     // Tokenize the string
     ostk1.SetString( osLine );
-    if( ostk1.CountTokens( ) < 3 )   return( FALSE );
+    if( ostk1.CountTokens( ) < 3 )   return( false );
 
     // Dispose of the first field
     ostk1.GetNextToken( );
@@ -296,8 +294,8 @@ bool  PrcNgSpice::bFmtDataLines( void )
         os1.Last( ) = wxT(' ');
         ostk1.GetNextToken( );
       }
-      if( ! ConvertType::bStrToDFlt( os1, &df1 ) ) df1 =      -9.999e+99;
-      if( ! ConvertType::bDFltToStr( df1, os1 ) )  os1 = wxT("-9.999e+99");
+      if( ! CnvtType::bStrToFlt( os1, &df1 ) ) df1 =      -9.999e+99;
+      if( ! CnvtType::bFltToStr( df1, os1 ) )  os1 = wxT("-9.999e+99");
       osLine << os1;
 
       // Pad the column with spaces to the required width
@@ -310,65 +308,66 @@ bool  PrcNgSpice::bFmtDataLines( void )
     osLine.Trim( ); // Remove trailing space characters
   }
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
-// Format any phase values contained in the results file (this is only
-// pertinent for AC analysis). It involves removing the discontinuity at 360
-// degree in the data.
+//**************************************************************************************************
+// Format any phase values contained in the results file.
+//
+// This is only pertinent for an AC analysis. It involves removing the discontinuity at 360 degree
+// in the data.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  PrcNgSpice::bFmtPhaseData( void )
 {
   // ??? (02/02/2006) Not yet implemented
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Make the process argument list based on the contents of a simulation object.
 //
 // Argument List :
 //   roSimn - The simulation object
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  PrcNgSpice::bMakeArgLst( SimnBase & roSimn )
 {
   wxString  os1;
 
   // Envoke the base class operations
-  if( ! PrcSimrBase::bMakeArgLst( roSimn ) ) return( FALSE );
+  if( ! PrcSimEngBase::bMakeArgLst( roSimn ) ) return( false );
 
   // Construct the command line to execute the simulation
   os1 = wxT("-n -b ") + roSimn.roGetSaveFile( ).GetFullPath( );
   if( ! PrcBase::bSetArgLst( os1 ) )
   {
     SetErrMsg( wxT("Couldn't set argument list") );
-    return( FALSE );
+    return( false );
   }
 
   // Get results file column labels (replace node pairs with component names)
   if( roSimn.eGetSimEng( ) == eSIMR_NGSPICE )
-    m_osColLbls = ((SimnNgSpice &) roSimn).rosGetColLbls( );
+    m_osColLbls = ((SimnNgSpice &) roSimn).m_oCmdPR.rosGetParamLst( );
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
-// Format the contents of the results file so that gWave can read it ie. a
-// header line at the top containing parameter names followed by the columns of
-// data.
+//**************************************************************************************************
+// Format the contents of the results file so that gWave can read it.
+//
+// Ie. add a header line at the top containing parameter names followed by the columns of data.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  PrcNgSpice::bFmtResults( void )
 {
@@ -384,7 +383,7 @@ bool  PrcNgSpice::bFmtResults( void )
     os1 << wxT("Results file doesn't exist : \n\n")
         << roGetResultsFile( ).GetFullPath( );
     SetErrMsg( os1 );
-    return( FALSE );
+    return( false );
   }
 
   // Attempt to open the results file
@@ -394,15 +393,17 @@ bool  PrcNgSpice::bFmtResults( void )
     os1 << wxT("Results file couldn't be opened : \n\n")
         << roGetResultsFile( ).GetFullPath( );
     SetErrMsg( os1 );
-    return( FALSE );
+    return( false );
   }
 
   // Format the simulation results
   bRtn = bFmtCommon( );
 
   // Need last line to end with a '\n' or text controls will not load it
-  if( m_oFileResults.GetLastLine( ).Last( ) != wxT('\n') )
-    m_oFileResults.GetLastLine( ) << wxT('\n');
+  os1 = m_oFileResults.GetLastLine( );
+  if( ! os1.IsEmpty( ) )
+    if( os1.Last( ) != wxT('\n') )
+      m_oFileResults.GetLastLine( ) << wxT('\n');
 
   m_oFileResults.Write( );  // Save the changes to disk
   m_oFileResults.Close( );  // Close the file
@@ -410,4 +411,4 @@ bool  PrcNgSpice::bFmtResults( void )
   return( bRtn );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
